@@ -176,7 +176,7 @@
                   proximity = as.double(proxmatrix),
                   nodes = as.integer(nodes),
                   nodexts = as.integer(nodexts),
-                  DUP=TRUE,
+                  DUP=FALSE,
                   PACKAGE = "randomForest")[keepIndex]
             ## Apply bias correction if needed.
             yhat <- rep(NA, length(rn))
@@ -208,30 +208,30 @@
         t1 <- .C("classForest",
                  mdim = as.integer(mdim),
                  ntest = as.integer(ntest),
-                 nclass = object$forest$nclass,
+                 nclass = as.integer(object$forest$nclass),
                  maxcat = as.integer(maxcat),
                  nrnodes = as.integer(nrnodes),
                  jbt = as.integer(ntree),
                  xts = as.double(x),
-                 xbestsplit = object$forest$xbestsplit,
+                 xbestsplit = as.double(object$forest$xbestsplit),
                  pid = object$forest$pid,
                  cutoff = as.double(cutoff),
                  countts = as.double(countts),
-                 treemap = aperm(object$forest$treemap,
-                 c(2, 1, 3)),
-                 nodestatus = object$forest$nodestatus,
-                 cat = object$forest$ncat,
-                 nodepred = object$forest$nodepred,
+                 treemap = as.integer(aperm(object$forest$treemap,
+                                 c(2, 1, 3))),
+                 nodestatus = as.integer(object$forest$nodestatus),
+                 cat = as.integer(object$forest$ncat),
+                 nodepred = as.integer(object$forest$nodepred),
                  treepred = as.integer(treepred),
                  jet = as.integer(numeric(ntest)),
-                 bestvar = object$forest$bestvar,
-                 nodexts = nodexts,
-                 ndbigtree = object$forest$ndbigtree,
+                 bestvar = as.integer(object$forest$bestvar),
+                 nodexts = as.integer(nodexts),
+                 ndbigtree = as.integer(object$forest$ndbigtree),
                  predict.all = as.integer(predict.all),
                  prox = as.integer(proximity),
                  proxmatrix = as.double(proxmatrix),
                  nodes = as.integer(nodes),
-                 DUP=TRUE,
+                 DUP=FALSE,
                  PACKAGE = "randomForest")
         if (out.type > 1) {
             out.class.votes <- t(matrix(t1$countts, nr = nclass, nc = ntest))
